@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 
-#ifndef HGCLONEDILAOG_H
-#define HGCLONEDILAOG_H
+#ifndef HGCLONEDIALOG_H
+#define HGCLONEDIALOG_H
 
 #include <QString>
 #include <QProcess>
@@ -41,7 +41,7 @@ class HgCloneDialog : public DialogBase
     Q_OBJECT
 
 public:
-    HgCloneDialog(const QString &directory, QWidget *parent = 0);
+    explicit HgCloneDialog(const QString &directory, QWidget *parent = 0);
     void setWorkingDirectory(const QString &directory);
 
 private slots:
@@ -88,5 +88,5 @@ private:
 
 };
 
-#endif // HGCLONEDILAOG_H
+#endif // HGCLONEDIALOG_H
 
